// Basic demo for accelerometer readings from Adafruit MPU6050

#include <Adafruit_NeoPixel.h>
#include <Adafruit_MPU6050.h>
#include <Adafruit_Sensor.h>
#include <Wire.h>
int A=0;
Adafruit_MPU6050 mpu;

#define LED_PIN    3
#define LED_COUNT 60

const int btn_pin = 4;
int val = 0; 
int state = 0; 
int old_val = 0; 

Adafruit_NeoPixel strip(LED_COUNT, LED_PIN, NEO_GRB + NEO_KHZ800);

void setup(void) {
  #if defined(_AVR_ATtiny85_) && (F_CPU == 16000000)
  clock_prescale_set(clock_div_1);
  #endif
  pinMode(btn_pin, INPUT_PULLUP);
  strip.begin();           
  strip.show();            
  strip.setBrightness(50); 
  Serial.begin(9600);
  while (!Serial)
    delay(10); // will pause Zero, Leonardo, etc until serial console opens

  Serial.println("Adafruit MPU6050 test!");

  // Try to initialize!
  if (!mpu.begin()) {
    Serial.println("Failed to find MPU6050 chip");
    while (1) {
      delay(10);
    }
  }

  strip.begin();           
  strip.show();            
  strip.setBrightness(50); 
  strip.clear();
  Serial.println("MPU6050 Found!");

  mpu.setAccelerometerRange(MPU6050_RANGE_8_G);
  Serial.print("Accelerometer range set to: ");
  switch (mpu.getAccelerometerRange()) {
  case MPU6050_RANGE_2_G:
    Serial.println("+-2G");
    break;
  case MPU6050_RANGE_4_G:
    Serial.println("+-4G");
    break;
  case MPU6050_RANGE_8_G:
    Serial.println("+-8G");
    break;
  case MPU6050_RANGE_16_G:
    Serial.println("+-16G");
    break;
  }
  mpu.setGyroRange(MPU6050_RANGE_500_DEG);
  Serial.print("Gyro range set to: ");
  switch (mpu.getGyroRange()) {
  case MPU6050_RANGE_250_DEG:
    Serial.println("+- 250 deg/s");
    break;
  case MPU6050_RANGE_500_DEG:
    Serial.println("+- 500 deg/s");
    break;
  case MPU6050_RANGE_1000_DEG:
    Serial.println("+- 1000 deg/s");
    break;
  case MPU6050_RANGE_2000_DEG:
    Serial.println("+- 2000 deg/s");
    break;
  }

  mpu.setFilterBandwidth(MPU6050_BAND_21_HZ);
  Serial.print("Filter bandwidth set to: ");
  switch (mpu.getFilterBandwidth()) {
  case MPU6050_BAND_260_HZ:
    Serial.println("260 Hz");
    break;
  case MPU6050_BAND_184_HZ:
    Serial.println("184 Hz");
    break;
  case MPU6050_BAND_94_HZ:
    Serial.println("94 Hz");
    break;
  case MPU6050_BAND_44_HZ:
    Serial.println("44 Hz");
    break;
  case MPU6050_BAND_21_HZ:
    Serial.println("21 Hz");
    break;
  case MPU6050_BAND_10_HZ:
    Serial.println("10 Hz");
    break;
  case MPU6050_BAND_5_HZ:
    Serial.println("5 Hz");
    break;
  }

  Serial.println("");
  delay(100);
}

void loop() {
  val= digitalRead(btn_pin); 
  if ((val == HIGH) && (old_val == LOW)){
    state=1-state;
    delay(10);
    }
  old_val = val; 

  /* Get new sensor events with the readings */
  sensors_event_t a, g, temp;
  mpu.getEvent(&a, &g, &temp);

  if (state==1){
  /* Print out the values */
  Serial.print("Acceleration X: ");
  Serial.println(a.acceleration.x);
  if(a.acceleration.x < 0) {
    A++;
    Serial.println(A);
    for(int i=0; i<strip.numPixels(); i++) { 
      strip.setPixelColor(i, 0, 255, 0);         
      strip.show();                          
      delay(10);                           
    }
  }

  if(a.acceleration.x > 0) {
      A++;
      Serial.println(A);
      for(int i=0; i<strip.numPixels(); i++) { 
        strip.setPixelColor(i, 0, 255, 171);         
        strip.show();                          
        delay(10);                           
      }
    }
  }
  if (state==0){
    colorWipe(strip.Color(255,   0,   0), 50); // Rojo
    colorWipe(strip.Color(  0, 255,   0), 50); // Verde
    colorWipe(strip.Color(  0,   0, 255), 50); // Azul
  
    theaterChase(strip.Color(127, 127, 127), 50); 
    theaterChase(strip.Color(127,   0,   0), 50); 
    theaterChase(strip.Color(  0,   0, 127), 50); 
  
    rainbow(10);         
  }
}

void colorWipe(uint32_t color, int wait) {
  for(int i=0; i<strip.numPixels(); i++) { 
    strip.setPixelColor(i, color);         
    strip.show();                          
    delay(wait);                           
  }
}


void theaterChase(uint32_t color, int wait) {
  for(int a=0; a<10; a++) { 
    for(int b=0; b<3; b++) { 
      strip.clear();         
      for(int c=b; c<strip.numPixels(); c += 3) {
        strip.setPixelColor(c, color); 
      }
      strip.show(); 
      delay(wait);  
    }
  }
}

void rainbow(int wait) {
    for(long firstPixelHue = 0; firstPixelHue < 5*65536; firstPixelHue += 256) {
    for(int i=0; i<strip.numPixels(); i++) { 
      int pixelHue = firstPixelHue + (i * 65536L / strip.numPixels());
      strip.setPixelColor(i, strip.gamma32(strip.ColorHSV(pixelHue)));
    }
    strip.show(); 
    delay(wait);
  }
}
